@@ -18,10 +18,10 @@ def simulate(config_file: (str, Path) = None, seq_file: (str, Path) = None):
     """
 
     if config_file is None:
-        config_file = Path(path.dirname(__file__)) / 'library' / 'sim-library' / 'config_example.yaml'
+        config_file = Path(path.dirname(__file__)) / 'library' / 'sim-library' / 'config_wasabi.yaml'
 
     if seq_file is None:
-        seq_file = Path(path.dirname(__file__)) / 'library' / 'seq-library' / 'seq_example.seq'
+        seq_file = Path(path.dirname(__file__)) / 'library' / 'seq-library' / 'WASABI.seq'
 
     # load config file(s)
     sim_params = load_params(config_file)
@@ -35,7 +35,7 @@ def simulate(config_file: (str, Path) = None, seq_file: (str, Path) = None):
     fig = plot_z(mz=mz,
                  offsets=offsets,
                  invert_ax=True,
-                 plot_mtr_asym=True,
+                 plot_mtr_asym=False,
                  title='Example WASABI spectrum')
 
 
